@@ -1,7 +1,7 @@
 import os
 from os import listdir
 
-HTML_TEMPLATE_PATH = 'html_template'
+HTML_TEMPLATE_PATH = 'kraken_html/html_template'
 
 html_templates = {}
 
