@@ -7,7 +7,10 @@ import requests
 
 #from models.html_form import Html_form
 
-
+# These lines ensure fiels are retrievable once packaged as a library
+import sys, os
+sys.path.append('kraken_html/content_template')
+sys.path.append('kraken_html/html_template')
 
 
 class Kraken_html:
